===============================
dupes
===============================

.. image:: https://img.shields.io/travis/dwwkelly/dupes.svg
        :target: https://travis-ci.org/dwwkelly/dupes

.. image:: https://img.shields.io/pypi/v/dupes.svg
        :target: https://pypi.python.org/pypi/dupes


Identify duplicate files (by SHA1) and remove them if needed

* Free software: GPL2 license
* Documentation: https://dupes.readthedocs.org.

Features
--------

* TODO
